==> phpgroupware-0.9.16.011.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/ct.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ct.php,v 1.1.2.1 2003/11/01 22:10:21 skwashd Exp $

$text['title']          = 'Informaci&oacute; del Sistema';

$text['vitals']         = 'Vitals del Sistema';
$text['hostname']       = 'Nom Cannic';
$text['ip']             = 'Adrea IP';
$text['kversion']       = 'Versi&oacute; del Kernel';
$text['uptime']         = 'Temps Aixecat';
$text['users']          = 'Usuaris Actuals';
$text['loadavg']        = 'Crrega Promitg';

$text['hardware']       = 'Informaci&oacute; del Maquinari';
$text['numcpu']         = 'Processadors';
$text['cpumodel']       = 'Model';
$text['mhz']            = 'Xip MHz';
$text['cache']          = 'Tamany Memria Cau';
$text['bogomips']       = 'Bogomips';
$text['pci']            = 'Dispositius PCI';
$text['ide']            = 'Dispositius IDE';
$text['scsi']           = 'Dispositius SCSI';

$text['netusage']       = 's de la Xarxa';
$text['device']         = 'Dispositiu';
$text['received']       = 'Rebuts';
$text['sent']           = 'Enviats';
$text['errors']         = 'Errors/Perduts';

$text['memusage']       = 's de la Memria';
$text['phymem']         = 'Memria F&iacute;sica';
$text['swap']           = 'Disc d\'Swap';

$text['fs']             = 'Sistemes d\'Arxius Muntats';
$text['mount']          = 'Muntat';
$text['partition']      = 'Partici';
$text['percent']        = 'Percentatge de Capacitat';
$text['type']           = 'Tipus';
$text['free']           = 'Lliure';
$text['used']           = 'Emprat';
$text['size']           = 'Tamany';
$text['totals']         = 'Totals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'cap';

$text['capacity']       = 'Capacitat';
  
$text['template']       = 'Plantilla';
$text['language']       = 'Llenga';
$text['submit']         = 'Enviar';
$text['created']        = 'Creat per';

$text['days']           = 'dies';
$text['hours']          = 'hores';
$text['minutes']        = 'minuts';
?>

==> phpgroupware-0.9.16.017.tbz: www/data-dist/phpgroupware/phpsysinfo/includes/lang/ct.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ct.php 21052 2010-03-25 22:44:08Z Caeies $

$text['title']          = 'Informaci&oacute; del Sistema';

$text['vitals']         = 'Vitals del Sistema';
$text['hostname']       = 'Nom Cannic';
$text['ip']             = 'Adrea IP';
$text['kversion']       = 'Versi&oacute; del Kernel';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Temps Aixecat';
$text['users']          = 'Usuaris Actuals';
$text['loadavg']        = 'Crrega Promitg';

$text['hardware']       = 'Informaci&oacute; del Maquinari';
$text['numcpu']         = 'Processadors';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Xip MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Tamany Memria Cau';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'Dispositius PCI';
$text['ide']            = 'Dispositius IDE';
$text['scsi']           = 'Dispositius SCSI';
$text['usb']            = 'Dispositius USB';

$text['netusage']       = 's de la Xarxa';
$text['device']         = 'Dispositiu';
$text['received']       = 'Rebuts';
$text['sent']           = 'Enviats';
$text['errors']         = 'Errors/Perduts';

$text['memusage']       = 's de la Memria';
$text['phymem']         = 'Memria F&iacute;sica';
$text['swap']           = 'Disc d\'Swap';

$text['fs']             = 'Sistemes d\'Arxius Muntats';
$text['mount']          = 'Muntat';
$text['partition']      = 'Partici';
$text['percent']        = 'Percentatge de Capacitat';
$text['type']           = 'Tipus';
$text['free']           = 'Lliure';
$text['used']           = 'Emprat';
$text['size']           = 'Tamany';
$text['totals']         = 'Totals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'cap';

$text['capacity']       = 'Capacitat';
  
$text['template']       = 'Plantilla';
$text['language']       = 'Llenga';
$text['submit']         = 'Enviar';
$text['created']        = 'Creat per';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dies';
$text['hours']          = 'hores';
$text['minutes']        = 'minuts';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
